==> haskell-hedgehog-1.0.5-92-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hedgehog.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hedgehog
version:              1.0.5
visibility:           public
id:                   hedgehog-1.0.5-3mQhj63GjqhHt7amnrVxxB
key:                  hedgehog-1.0.5-3mQhj63GjqhHt7amnrVxxB
license:              BSD-3-Clause
maintainer:           Jacob Stanley <jacob@stanley.io>
author:               Jacob Stanley
homepage:             https://hedgehog.qa
synopsis:             Release with confidence.
description:
    <http://hedgehog.qa/ Hedgehog> automatically generates a comprehensive array
    of test cases, exercising your software in ways human testers would never
    imagine.

    Generate hundreds of test cases automatically, exposing even the
    most insidious of corner cases. Failures are automatically simplified, giving
    developers coherent, intelligible error messages.

    To get started quickly, see the <https://github.com/hedgehogqa/haskell-hedgehog/tree/master/hedgehog-example examples>.

category:             Testing
abi:                  4446072723d4963ba34536cd85fa81fb
exposed:              True
exposed-modules:
    Hedgehog Hedgehog.Gen Hedgehog.Internal.Config
    Hedgehog.Internal.Discovery Hedgehog.Internal.Distributive
    Hedgehog.Internal.Exception Hedgehog.Internal.Gen
    Hedgehog.Internal.HTraversable Hedgehog.Internal.Opaque
    Hedgehog.Internal.Prelude Hedgehog.Internal.Property
    Hedgehog.Internal.Queue Hedgehog.Internal.Range
    Hedgehog.Internal.Region Hedgehog.Internal.Report
    Hedgehog.Internal.Runner Hedgehog.Internal.Seed
    Hedgehog.Internal.Show Hedgehog.Internal.Shrink
    Hedgehog.Internal.Source Hedgehog.Internal.State
    Hedgehog.Internal.TH Hedgehog.Internal.Tree
    Hedgehog.Internal.Tripping Hedgehog.Main Hedgehog.Range

import-dirs:          /usr/lib/ghc-9.0.2/site-local/hedgehog-1.0.5
library-dirs:         /usr/lib/ghc-9.0.2/site-local/hedgehog-1.0.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.2/hedgehog-1.0.5
hs-libraries:         HShedgehog-1.0.5-3mQhj63GjqhHt7amnrVxxB
depends:
    ansi-terminal-0.11-7Sg6KtenVNR9Ce5shok5FD
    async-2.2.4-KDuVI0AzzpKOLY6VEiTcY base-4.15.1.0
    bytestring-0.10.12.1
    concurrent-output-1.10.13-1n8A7oApWjMFpqxq8SGZat containers-0.6.4.1
    deepseq-1.4.5.0 directory-1.3.6.2
    erf-2.0.0.0-HR6qYigvkwv59tgVmdiMH1 exceptions-0.10.4
    lifted-async-0.10.2.2-5F0pb8mBy3V7WOMqdo7ZP6
    mmorph-1.2.0-rUcqJ8kf022ZNG6tH16A7
    monad-control-1.0.3.1-5iZm1T1pYh8IGY1NTmHB3e mtl-2.2.2
    pretty-show-1.10-30ddFMLbEm1DQ0GcmAHjnN
    primitive-0.7.3.0-B50m1vBTvOqCDtGqJqReDJ
    random-1.2.1-B9QyR7akHvI3KPtL26m3EE
    resourcet-1.2.4.3-ADc9MHSIw28LYfy4t6jiSB stm-2.5.0.0
    template-haskell-2.17.0.0 text-1.2.5.0 time-1.9.3
    transformers-0.5.6.2 transformers-base-0.4.6-JYrdXigsUd5LO1F0gUSlKl
    wl-pprint-annotated-0.1.0.1-3CCV5RVIb0J3hlSqzWWBEz

haddock-interfaces:   /usr/share/doc/haskell-hedgehog/html/hedgehog.haddock
haddock-html:         /usr/share/doc/haskell-hedgehog/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hedgehog-1.0.5-93-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hedgehog.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hedgehog
version:              1.0.5
visibility:           public
id:                   hedgehog-1.0.5-2Ww3LVzodBbBlw49iH033B
key:                  hedgehog-1.0.5-2Ww3LVzodBbBlw49iH033B
license:              BSD-3-Clause
maintainer:           Jacob Stanley <jacob@stanley.io>
author:               Jacob Stanley
homepage:             https://hedgehog.qa
synopsis:             Release with confidence.
description:
    <http://hedgehog.qa/ Hedgehog> automatically generates a comprehensive array
    of test cases, exercising your software in ways human testers would never
    imagine.

    Generate hundreds of test cases automatically, exposing even the
    most insidious of corner cases. Failures are automatically simplified, giving
    developers coherent, intelligible error messages.

    To get started quickly, see the <https://github.com/hedgehogqa/haskell-hedgehog/tree/master/hedgehog-example examples>.

category:             Testing
abi:                  3a7c26288c7ace2291356bc62db60fb4
exposed:              True
exposed-modules:
    Hedgehog Hedgehog.Gen Hedgehog.Internal.Config
    Hedgehog.Internal.Discovery Hedgehog.Internal.Distributive
    Hedgehog.Internal.Exception Hedgehog.Internal.Gen
    Hedgehog.Internal.HTraversable Hedgehog.Internal.Opaque
    Hedgehog.Internal.Prelude Hedgehog.Internal.Property
    Hedgehog.Internal.Queue Hedgehog.Internal.Range
    Hedgehog.Internal.Region Hedgehog.Internal.Report
    Hedgehog.Internal.Runner Hedgehog.Internal.Seed
    Hedgehog.Internal.Show Hedgehog.Internal.Shrink
    Hedgehog.Internal.Source Hedgehog.Internal.State
    Hedgehog.Internal.TH Hedgehog.Internal.Tree
    Hedgehog.Internal.Tripping Hedgehog.Main Hedgehog.Range

import-dirs:          /usr/lib/ghc-9.0.2/site-local/hedgehog-1.0.5
library-dirs:         /usr/lib/ghc-9.0.2/site-local/hedgehog-1.0.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.2/hedgehog-1.0.5
hs-libraries:         HShedgehog-1.0.5-2Ww3LVzodBbBlw49iH033B
depends:
    ansi-terminal-0.11-7Sg6KtenVNR9Ce5shok5FD
    async-2.2.4-JjkqNdD7aK042AYqCMjiPJ base-4.15.1.0
    bytestring-0.10.12.1
    concurrent-output-1.10.13-5ADwtuIudJV6Tzd4nkHcWF containers-0.6.4.1
    deepseq-1.4.5.0 directory-1.3.6.2
    erf-2.0.0.0-HR6qYigvkwv59tgVmdiMH1 exceptions-0.10.4
    lifted-async-0.10.2.2-Ef2YHBifZ5T7XvTV2L4Mzg
    mmorph-1.2.0-rUcqJ8kf022ZNG6tH16A7
    monad-control-1.0.3.1-84jOTbsrw8SEyFFHHz1LDD mtl-2.2.2
    pretty-show-1.10-30ddFMLbEm1DQ0GcmAHjnN
    primitive-0.7.3.0-6mJnOlsjOaQ2INtjd9hIci
    random-1.2.1-7EGiiwGUfK5IqCEnMWzSRN
    resourcet-1.2.4.3-4RZW3x96Q2NL72qCmJm85P stm-2.5.0.0
    template-haskell-2.17.0.0 text-1.2.5.0 time-1.9.3
    transformers-0.5.6.2 transformers-base-0.4.6-8naGXAtg3oZKHRLkolBCeN
    wl-pprint-annotated-0.1.0.1-8CsxFNTGvWi7lrqAQbUb7g

haddock-interfaces:   /usr/share/doc/haskell-hedgehog/html/hedgehog.haddock
haddock-html:         /usr/share/doc/haskell-hedgehog/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
